# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class Experiment(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'created_dt': 'datetime',
        'active': 'bool',
        'name': 'str',
        'hypothesis': 'str',
        'control': 'int',
        'treatments': 'list[int]',
        'notion_url': 'str'
    }

    attribute_map = {
        'id': 'id',
        'created_dt': 'created_dt',
        'active': 'active',
        'name': 'name',
        'hypothesis': 'hypothesis',
        'control': 'control',
        'treatments': 'treatments',
        'notion_url': 'notion_url'
    }

    def __init__(self, id=None, created_dt=None, active=None, name=None, hypothesis=None, control=None, treatments=None, notion_url=None, local_vars_configuration=None):  # noqa: E501
        """Experiment - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._created_dt = None
        self._active = None
        self._name = None
        self._hypothesis = None
        self._control = None
        self._treatments = None
        self._notion_url = None
        self.discriminator = None

        self.id = id
        self.created_dt = created_dt
        if active is not None:
            self.active = active
        self.name = name
        self.hypothesis = hypothesis
        self.control = control
        if treatments is not None:
            self.treatments = treatments
        self.notion_url = notion_url

    @property
    def id(self):
        """Gets the id of this Experiment.  # noqa: E501


        :return: The id of this Experiment.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Experiment.


        :param id: The id of this Experiment.  # noqa: E501
        :type id: int
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def created_dt(self):
        """Gets the created_dt of this Experiment.  # noqa: E501


        :return: The created_dt of this Experiment.  # noqa: E501
        :rtype: datetime
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this Experiment.


        :param created_dt: The created_dt of this Experiment.  # noqa: E501
        :type created_dt: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_dt is None:  # noqa: E501
            raise ValueError("Invalid value for `created_dt`, must not be `None`")  # noqa: E501

        self._created_dt = created_dt

    @property
    def active(self):
        """Gets the active of this Experiment.  # noqa: E501


        :return: The active of this Experiment.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this Experiment.


        :param active: The active of this Experiment.  # noqa: E501
        :type active: bool
        """

        self._active = active

    @property
    def name(self):
        """Gets the name of this Experiment.  # noqa: E501


        :return: The name of this Experiment.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Experiment.


        :param name: The name of this Experiment.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 255):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `255`")  # noqa: E501

        self._name = name

    @property
    def hypothesis(self):
        """Gets the hypothesis of this Experiment.  # noqa: E501


        :return: The hypothesis of this Experiment.  # noqa: E501
        :rtype: str
        """
        return self._hypothesis

    @hypothesis.setter
    def hypothesis(self, hypothesis):
        """Sets the hypothesis of this Experiment.


        :param hypothesis: The hypothesis of this Experiment.  # noqa: E501
        :type hypothesis: str
        """
        if self.local_vars_configuration.client_side_validation and hypothesis is None:  # noqa: E501
            raise ValueError("Invalid value for `hypothesis`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                hypothesis is not None and len(hypothesis) > 255):
            raise ValueError("Invalid value for `hypothesis`, length must be less than or equal to `255`")  # noqa: E501

        self._hypothesis = hypothesis

    @property
    def control(self):
        """Gets the control of this Experiment.  # noqa: E501


        :return: The control of this Experiment.  # noqa: E501
        :rtype: int
        """
        return self._control

    @control.setter
    def control(self, control):
        """Sets the control of this Experiment.


        :param control: The control of this Experiment.  # noqa: E501
        :type control: int
        """
        if self.local_vars_configuration.client_side_validation and control is None:  # noqa: E501
            raise ValueError("Invalid value for `control`, must not be `None`")  # noqa: E501

        self._control = control

    @property
    def treatments(self):
        """Gets the treatments of this Experiment.  # noqa: E501


        :return: The treatments of this Experiment.  # noqa: E501
        :rtype: list[int]
        """
        return self._treatments

    @treatments.setter
    def treatments(self, treatments):
        """Sets the treatments of this Experiment.


        :param treatments: The treatments of this Experiment.  # noqa: E501
        :type treatments: list[int]
        """

        self._treatments = treatments

    @property
    def notion_url(self):
        """Gets the notion_url of this Experiment.  # noqa: E501


        :return: The notion_url of this Experiment.  # noqa: E501
        :rtype: str
        """
        return self._notion_url

    @notion_url.setter
    def notion_url(self, notion_url):
        """Sets the notion_url of this Experiment.


        :param notion_url: The notion_url of this Experiment.  # noqa: E501
        :type notion_url: str
        """
        if (self.local_vars_configuration.client_side_validation and
                notion_url is not None and len(notion_url) > 255):
            raise ValueError("Invalid value for `notion_url`, length must be less than or equal to `255`")  # noqa: E501

        self._notion_url = notion_url

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Experiment):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Experiment):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import printnanny_api_client
from printnanny_api_client.models.device import Device  # noqa: E501
from printnanny_api_client.rest import ApiException

class TestDevice(unittest.TestCase):
    """Device unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Device
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = printnanny_api_client.models.device.Device()  # noqa: E501
        if include_optional :
            return Device(
                id = 56, 
                cloudiot_device = None, 
                cameras = [
                    printnanny_api_client.models.camera.Camera(
                        id = 56, 
                        deleted = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        created_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        active = True, 
                        device = 56, 
                        name = 'Raspberry Pi Cam', 
                        camera_type = null, )
                    ], 
                janus_local_url = '', 
                dashboard_url = '', 
                printer_controllers = [
                    printnanny_api_client.models.printer_controller.PrinterController(
                        id = 56, 
                        software = null, 
                        created_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        polymorphic_ctype = 56, 
                        user = 56, 
                        device = 56, )
                    ], 
                release_channel = None, 
                monitoring_active = True, 
                user = None, 
                last_task = None, 
                active_tasks = [
                    printnanny_api_client.models.task.Task(
                        id = 56, 
                        last_status = null, 
                        task_type = 'monitor_start', 
                        active = True, 
                        task_type_display = '', 
                        created_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        device = 56, )
                    ], 
                active_cameras = [
                    printnanny_api_client.models.camera.Camera(
                        id = 56, 
                        deleted = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        created_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        active = True, 
                        device = 56, 
                        name = 'Raspberry Pi Cam', 
                        camera_type = null, )
                    ], 
                created_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                updated_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                hostname = ''
            )
        else :
            return Device(
                id = 56,
                cloudiot_device = None,
                cameras = [
                    printnanny_api_client.models.camera.Camera(
                        id = 56, 
                        deleted = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        created_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        active = True, 
                        device = 56, 
                        name = 'Raspberry Pi Cam', 
                        camera_type = null, )
                    ],
                janus_local_url = '',
                dashboard_url = '',
                printer_controllers = [
                    printnanny_api_client.models.printer_controller.PrinterController(
                        id = 56, 
                        software = null, 
                        created_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        polymorphic_ctype = 56, 
                        user = 56, 
                        device = 56, )
                    ],
                user = None,
                last_task = None,
                active_tasks = [
                    printnanny_api_client.models.task.Task(
                        id = 56, 
                        last_status = null, 
                        task_type = 'monitor_start', 
                        active = True, 
                        task_type_display = '', 
                        created_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        device = 56, )
                    ],
                active_cameras = [
                    printnanny_api_client.models.camera.Camera(
                        id = 56, 
                        deleted = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        created_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        active = True, 
                        device = 56, 
                        name = 'Raspberry Pi Cam', 
                        camera_type = null, )
                    ],
                created_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
        )

    def testDevice(self):
        """Test Device"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class OctoprintJob(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'file': 'OctoprintFile',
        'estimated_print_time': 'float',
        'average_print_time': 'float',
        'last_print_time': 'float',
        'filament': 'dict(str, object)'
    }

    attribute_map = {
        'file': 'file',
        'estimated_print_time': 'estimatedPrintTime',
        'average_print_time': 'averagePrintTime',
        'last_print_time': 'lastPrintTime',
        'filament': 'filament'
    }

    def __init__(self, file=None, estimated_print_time=None, average_print_time=None, last_print_time=None, filament=None, local_vars_configuration=None):  # noqa: E501
        """OctoprintJob - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._file = None
        self._estimated_print_time = None
        self._average_print_time = None
        self._last_print_time = None
        self._filament = None
        self.discriminator = None

        self.file = file
        self.estimated_print_time = estimated_print_time
        self.average_print_time = average_print_time
        self.last_print_time = last_print_time
        self.filament = filament

    @property
    def file(self):
        """Gets the file of this OctoprintJob.  # noqa: E501


        :return: The file of this OctoprintJob.  # noqa: E501
        :rtype: OctoprintFile
        """
        return self._file

    @file.setter
    def file(self, file):
        """Sets the file of this OctoprintJob.


        :param file: The file of this OctoprintJob.  # noqa: E501
        :type file: OctoprintFile
        """

        self._file = file

    @property
    def estimated_print_time(self):
        """Gets the estimated_print_time of this OctoprintJob.  # noqa: E501


        :return: The estimated_print_time of this OctoprintJob.  # noqa: E501
        :rtype: float
        """
        return self._estimated_print_time

    @estimated_print_time.setter
    def estimated_print_time(self, estimated_print_time):
        """Sets the estimated_print_time of this OctoprintJob.


        :param estimated_print_time: The estimated_print_time of this OctoprintJob.  # noqa: E501
        :type estimated_print_time: float
        """

        self._estimated_print_time = estimated_print_time

    @property
    def average_print_time(self):
        """Gets the average_print_time of this OctoprintJob.  # noqa: E501


        :return: The average_print_time of this OctoprintJob.  # noqa: E501
        :rtype: float
        """
        return self._average_print_time

    @average_print_time.setter
    def average_print_time(self, average_print_time):
        """Sets the average_print_time of this OctoprintJob.


        :param average_print_time: The average_print_time of this OctoprintJob.  # noqa: E501
        :type average_print_time: float
        """

        self._average_print_time = average_print_time

    @property
    def last_print_time(self):
        """Gets the last_print_time of this OctoprintJob.  # noqa: E501


        :return: The last_print_time of this OctoprintJob.  # noqa: E501
        :rtype: float
        """
        return self._last_print_time

    @last_print_time.setter
    def last_print_time(self, last_print_time):
        """Sets the last_print_time of this OctoprintJob.


        :param last_print_time: The last_print_time of this OctoprintJob.  # noqa: E501
        :type last_print_time: float
        """

        self._last_print_time = last_print_time

    @property
    def filament(self):
        """Gets the filament of this OctoprintJob.  # noqa: E501


        :return: The filament of this OctoprintJob.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._filament

    @filament.setter
    def filament(self, filament):
        """Sets the filament of this OctoprintJob.


        :param filament: The filament of this OctoprintJob.  # noqa: E501
        :type filament: dict(str, object)
        """

        self._filament = filament

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OctoprintJob):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OctoprintJob):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import printnanny_api_client
from printnanny_api_client.api.ml_ops_api import MlOpsApi  # noqa: E501
from printnanny_api_client.rest import ApiException


class TestMlOpsApi(unittest.TestCase):
    """MlOpsApi unit test stubs"""

    def setUp(self):
        self.api = printnanny_api_client.api.ml_ops_api.MlOpsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_device_calibration_update_or_create(self):
        """Test case for device_calibration_update_or_create

        """
        pass

    def test_device_calibrations_list(self):
        """Test case for device_calibrations_list

        """
        pass

    def test_device_calibrations_partial_update(self):
        """Test case for device_calibrations_partial_update

        """
        pass

    def test_device_calibrations_retrieve(self):
        """Test case for device_calibrations_retrieve

        """
        pass

    def test_device_calibrations_update(self):
        """Test case for device_calibrations_update

        """
        pass

    def test_experiment_device_configs_list(self):
        """Test case for experiment_device_configs_list

        """
        pass

    def test_experiment_device_configs_retrieve(self):
        """Test case for experiment_device_configs_retrieve

        """
        pass

    def test_experiments_list(self):
        """Test case for experiments_list

        """
        pass

    def test_experiments_retrieve(self):
        """Test case for experiments_retrieve

        """
        pass

    def test_model_artifacts_list(self):
        """Test case for model_artifacts_list

        """
        pass

    def test_model_artifacts_retrieve(self):
        """Test case for model_artifacts_retrieve

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class OctoTelemetryEvent(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    allowed enum values
    """
    PLUGIN_OCTOPRINT_NANNY_MONITORING_START = "plugin_octoprint_nanny_monitoring_start"
    PLUGIN_OCTOPRINT_NANNY_MONITORING_STOP = "plugin_octoprint_nanny_monitoring_stop"
    PLUGIN_OCTOPRINT_NANNY_MONITORING_RESET = "plugin_octoprint_nanny_monitoring_reset"
    PLUGIN_OCTOPRINT_NANNY_DEVICE_REGISTER_START = "plugin_octoprint_nanny_device_register_start"
    PLUGIN_OCTOPRINT_NANNY_DEVICE_REGISTER_DONE = "plugin_octoprint_nanny_device_register_done"
    PLUGIN_OCTOPRINT_NANNY_DEVICE_REGISTER_FAILED = "plugin_octoprint_nanny_device_register_failed"
    PLUGIN_OCTOPRINT_NANNY_DEVICE_RESET = "plugin_octoprint_nanny_device_reset"
    PLUGIN_OCTOPRINT_NANNY_PRINTER_PROFILE_SYNC_START = "plugin_octoprint_nanny_printer_profile_sync_start"
    PLUGIN_OCTOPRINT_NANNY_PRINTER_PROFILE_SYNC_DONE = "plugin_octoprint_nanny_printer_profile_sync_done"
    PLUGIN_OCTOPRINT_NANNY_PRINTER_PROFILE_SYNC_FAILED = "plugin_octoprint_nanny_printer_profile_sync_failed"
    PLUGIN_OCTOPRINT_NANNY_CONNECT_TEST_REST_API = "plugin_octoprint_nanny_connect_test_rest_api"
    PLUGIN_OCTOPRINT_NANNY_CONNECT_TEST_REST_API_FAILED = "plugin_octoprint_nanny_connect_test_rest_api_failed"
    PLUGIN_OCTOPRINT_NANNY_CONNECT_TEST_REST_API_SUCCESS = "plugin_octoprint_nanny_connect_test_rest_api_success"
    PLUGIN_OCTOPRINT_NANNY_CONNECT_TEST_MQTT_PING = "plugin_octoprint_nanny_connect_test_mqtt_ping"
    PLUGIN_OCTOPRINT_NANNY_CONNECT_TEST_MQTT_PING_FAILED = "plugin_octoprint_nanny_connect_test_mqtt_ping_failed"
    PLUGIN_OCTOPRINT_NANNY_CONNECT_TEST_MQTT_PING_SUCCESS = "plugin_octoprint_nanny_connect_test_mqtt_ping_success"
    PLUGIN_OCTOPRINT_NANNY_CONNECT_TEST_MQTT_PONG = "plugin_octoprint_nanny_connect_test_mqtt_pong"
    PLUGIN_OCTOPRINT_NANNY_CONNECT_TEST_MQTT_PONG_FAILED = "plugin_octoprint_nanny_connect_test_mqtt_pong_failed"
    PLUGIN_OCTOPRINT_NANNY_CONNECT_TEST_MQTT_PONG_SUCCESS = "plugin_octoprint_nanny_connect_test_mqtt_pong_success"
    CONNECT_TEST_NOOP = "connect_test_noop"
    CLIENTAUTHED = "ClientAuthed"
    CLIENTCLOSED = "ClientClosed"
    CLIENTDEAUTHED = "ClientDeauthed"
    CLIENTOPENED = "ClientOpened"
    SETTINGSUPDATED = "SettingsUpdated"
    USERLOGGEDIN = "UserLoggedIn"
    USERLOGGEDOUT = "UserLoggedOut"
    FILEADDED = "FileAdded"
    FILEREMOVED = "FileRemoved"
    FOLDERADDED = "FolderAdded"
    FOLDERREMOVED = "FolderRemoved"
    TRANSFERDONE = "TransferDone"
    TRANSFERFAILED = "TransferFailed"
    TRANSFERSTARTED = "TransferStarted"
    UPDATEDFILES = "UpdatedFiles"
    UPLOAD = "Upload"
    CAPTUREDONE = "CaptureDone"
    CAPTUREFAILED = "CaptureFailed"
    CAPTURESTART = "CaptureStart"
    MOVIEDONE = "MovieDone"
    MOVIEFAILED = "MovieFailed"
    MOVIERENDERING = "MovieRendering"
    POSTROLLEND = "PostRollEnd"
    POSTROLLSTART = "PostRollStart"
    SLICINGCANCELLED = "SlicingCancelled"
    SLICINGDONE = "SlicingDone"
    SLICINGFAILED = "SlicingFailed"
    SLICINGPROFILEADDED = "SlicingProfileAdded"
    SLICINGPROFILEDELETED = "SlicingProfileDeleted"
    SLICINGPROFILEMODIFIED = "SlicingProfileModified"
    SLICINGSTARTED = "SlicingStarted"
    CONNECTED = "Connected"
    DISCONNECTED = "Disconnected"
    PRINTERRESET = "PrinterReset"
    FIRMWAREDATA = "FirmwareData"
    PRINTERPROFILEADDED = "PrinterProfileAdded"
    PRINTERPROFILEDELETED = "PrinterProfileDeleted"
    PRINTERPROFILEMODIFIED = "PrinterProfileModified"
    PRINTPROGRESS = "PrintProgress"
    PLUGIN_PI_SUPPORT_THROTTLE_STATE = "plugin_pi_support_throttle_state"
    SHUTDOWN = "Shutdown"
    STARTUP = "Startup"
    REMOTE_COMMAND_RECEIVED = "remote_command_received"
    REMOTE_COMMAND_FAILED = "remote_command_failed"
    REMOTE_COMMAND_SUCCESS = "remote_command_success"
    PRINTCANCELLED = "PrintCancelled"
    PRINTCANCELLING = "PrintCancelling"
    PRINTDONE = "PrintDone"
    PRINTFAILED = "PrintFailed"
    PRINTPAUSED = "PrintPaused"
    PRINTRESUMED = "PrintResumed"
    PRINTSTARTED = "PrintStarted"
    PRINTERSTATECHANGED = "PrinterStateChanged"

    allowable_values = [PLUGIN_OCTOPRINT_NANNY_MONITORING_START, PLUGIN_OCTOPRINT_NANNY_MONITORING_STOP, PLUGIN_OCTOPRINT_NANNY_MONITORING_RESET, PLUGIN_OCTOPRINT_NANNY_DEVICE_REGISTER_START, PLUGIN_OCTOPRINT_NANNY_DEVICE_REGISTER_DONE, PLUGIN_OCTOPRINT_NANNY_DEVICE_REGISTER_FAILED, PLUGIN_OCTOPRINT_NANNY_DEVICE_RESET, PLUGIN_OCTOPRINT_NANNY_PRINTER_PROFILE_SYNC_START, PLUGIN_OCTOPRINT_NANNY_PRINTER_PROFILE_SYNC_DONE, PLUGIN_OCTOPRINT_NANNY_PRINTER_PROFILE_SYNC_FAILED, PLUGIN_OCTOPRINT_NANNY_CONNECT_TEST_REST_API, PLUGIN_OCTOPRINT_NANNY_CONNECT_TEST_REST_API_FAILED, PLUGIN_OCTOPRINT_NANNY_CONNECT_TEST_REST_API_SUCCESS, PLUGIN_OCTOPRINT_NANNY_CONNECT_TEST_MQTT_PING, PLUGIN_OCTOPRINT_NANNY_CONNECT_TEST_MQTT_PING_FAILED, PLUGIN_OCTOPRINT_NANNY_CONNECT_TEST_MQTT_PING_SUCCESS, PLUGIN_OCTOPRINT_NANNY_CONNECT_TEST_MQTT_PONG, PLUGIN_OCTOPRINT_NANNY_CONNECT_TEST_MQTT_PONG_FAILED, PLUGIN_OCTOPRINT_NANNY_CONNECT_TEST_MQTT_PONG_SUCCESS, CONNECT_TEST_NOOP, CLIENTAUTHED, CLIENTCLOSED, CLIENTDEAUTHED, CLIENTOPENED, SETTINGSUPDATED, USERLOGGEDIN, USERLOGGEDOUT, FILEADDED, FILEREMOVED, FOLDERADDED, FOLDERREMOVED, TRANSFERDONE, TRANSFERFAILED, TRANSFERSTARTED, UPDATEDFILES, UPLOAD, CAPTUREDONE, CAPTUREFAILED, CAPTURESTART, MOVIEDONE, MOVIEFAILED, MOVIERENDERING, POSTROLLEND, POSTROLLSTART, SLICINGCANCELLED, SLICINGDONE, SLICINGFAILED, SLICINGPROFILEADDED, SLICINGPROFILEDELETED, SLICINGPROFILEMODIFIED, SLICINGSTARTED, CONNECTED, DISCONNECTED, PRINTERRESET, FIRMWAREDATA, PRINTERPROFILEADDED, PRINTERPROFILEDELETED, PRINTERPROFILEMODIFIED, PRINTPROGRESS, PLUGIN_PI_SUPPORT_THROTTLE_STATE, SHUTDOWN, STARTUP, REMOTE_COMMAND_RECEIVED, REMOTE_COMMAND_FAILED, REMOTE_COMMAND_SUCCESS, PRINTCANCELLED, PRINTCANCELLING, PRINTDONE, PRINTFAILED, PRINTPAUSED, PRINTRESUMED, PRINTSTARTED, PRINTERSTATECHANGED]  # noqa: E501

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
    }

    attribute_map = {
    }

    def __init__(self, local_vars_configuration=None):  # noqa: E501
        """OctoTelemetryEvent - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration
        self.discriminator = None

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OctoTelemetryEvent):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OctoTelemetryEvent):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import printnanny_api_client
from printnanny_api_client.models.octoprint_environment_request import OctoprintEnvironmentRequest  # noqa: E501
from printnanny_api_client.rest import ApiException

class TestOctoprintEnvironmentRequest(unittest.TestCase):
    """OctoprintEnvironmentRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test OctoprintEnvironmentRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = printnanny_api_client.models.octoprint_environment_request.OctoprintEnvironmentRequest()  # noqa: E501
        if include_optional :
            return OctoprintEnvironmentRequest(
                os = printnanny_api_client.models.octoprint_platform_request.OctoprintPlatformRequest(
                    id = '0', 
                    platform = '0', 
                    bits = '0', ), 
                python = printnanny_api_client.models.octoprint_python_request.OctoprintPythonRequest(
                    version = '0', 
                    pip = '0', 
                    virtualenv = '0', ), 
                hardware = printnanny_api_client.models.octoprint_hardware_request.OctoprintHardwareRequest(
                    cores = 56, 
                    freq = 1.337, 
                    ram = 56, ), 
                pi_support = printnanny_api_client.models.octoprint_pi_support_request.OctoprintPiSupportRequest(
                    model = '0', 
                    throttle_state = '0', 
                    octopi_version = '0', )
            )
        else :
            return OctoprintEnvironmentRequest(
                os = printnanny_api_client.models.octoprint_platform_request.OctoprintPlatformRequest(
                    id = '0', 
                    platform = '0', 
                    bits = '0', ),
                python = printnanny_api_client.models.octoprint_python_request.OctoprintPythonRequest(
                    version = '0', 
                    pip = '0', 
                    virtualenv = '0', ),
                hardware = printnanny_api_client.models.octoprint_hardware_request.OctoprintHardwareRequest(
                    cores = 56, 
                    freq = 1.337, 
                    ram = 56, ),
                pi_support = printnanny_api_client.models.octoprint_pi_support_request.OctoprintPiSupportRequest(
                    model = '0', 
                    throttle_state = '0', 
                    octopi_version = '0', ),
        )

    def testOctoprintEnvironmentRequest(self):
        """Test OctoprintEnvironmentRequest"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class ModelArtifact(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'created_dt': 'datetime',
        'version': 'str',
        'labels': 'str',
        'artifacts': 'str',
        'artifact_types': 'list[ArtifactTypesEnum]',
        'metadata': 'dict(str, object)',
        'url': 'str'
    }

    attribute_map = {
        'id': 'id',
        'created_dt': 'created_dt',
        'version': 'version',
        'labels': 'labels',
        'artifacts': 'artifacts',
        'artifact_types': 'artifact_types',
        'metadata': 'metadata',
        'url': 'url'
    }

    def __init__(self, id=None, created_dt=None, version=None, labels=None, artifacts=None, artifact_types=None, metadata=None, url=None, local_vars_configuration=None):  # noqa: E501
        """ModelArtifact - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._created_dt = None
        self._version = None
        self._labels = None
        self._artifacts = None
        self._artifact_types = None
        self._metadata = None
        self._url = None
        self.discriminator = None

        self.id = id
        self.created_dt = created_dt
        self.version = version
        self.labels = labels
        self.artifacts = artifacts
        self.artifact_types = artifact_types
        self.metadata = metadata
        self.url = url

    @property
    def id(self):
        """Gets the id of this ModelArtifact.  # noqa: E501


        :return: The id of this ModelArtifact.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ModelArtifact.


        :param id: The id of this ModelArtifact.  # noqa: E501
        :type id: int
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def created_dt(self):
        """Gets the created_dt of this ModelArtifact.  # noqa: E501


        :return: The created_dt of this ModelArtifact.  # noqa: E501
        :rtype: datetime
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this ModelArtifact.


        :param created_dt: The created_dt of this ModelArtifact.  # noqa: E501
        :type created_dt: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_dt is None:  # noqa: E501
            raise ValueError("Invalid value for `created_dt`, must not be `None`")  # noqa: E501

        self._created_dt = created_dt

    @property
    def version(self):
        """Gets the version of this ModelArtifact.  # noqa: E501


        :return: The version of this ModelArtifact.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this ModelArtifact.


        :param version: The version of this ModelArtifact.  # noqa: E501
        :type version: str
        """
        if self.local_vars_configuration.client_side_validation and version is None:  # noqa: E501
            raise ValueError("Invalid value for `version`, must not be `None`")  # noqa: E501

        self._version = version

    @property
    def labels(self):
        """Gets the labels of this ModelArtifact.  # noqa: E501


        :return: The labels of this ModelArtifact.  # noqa: E501
        :rtype: str
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """Sets the labels of this ModelArtifact.


        :param labels: The labels of this ModelArtifact.  # noqa: E501
        :type labels: str
        """
        if self.local_vars_configuration.client_side_validation and labels is None:  # noqa: E501
            raise ValueError("Invalid value for `labels`, must not be `None`")  # noqa: E501

        self._labels = labels

    @property
    def artifacts(self):
        """Gets the artifacts of this ModelArtifact.  # noqa: E501


        :return: The artifacts of this ModelArtifact.  # noqa: E501
        :rtype: str
        """
        return self._artifacts

    @artifacts.setter
    def artifacts(self, artifacts):
        """Sets the artifacts of this ModelArtifact.


        :param artifacts: The artifacts of this ModelArtifact.  # noqa: E501
        :type artifacts: str
        """
        if self.local_vars_configuration.client_side_validation and artifacts is None:  # noqa: E501
            raise ValueError("Invalid value for `artifacts`, must not be `None`")  # noqa: E501

        self._artifacts = artifacts

    @property
    def artifact_types(self):
        """Gets the artifact_types of this ModelArtifact.  # noqa: E501


        :return: The artifact_types of this ModelArtifact.  # noqa: E501
        :rtype: list[ArtifactTypesEnum]
        """
        return self._artifact_types

    @artifact_types.setter
    def artifact_types(self, artifact_types):
        """Sets the artifact_types of this ModelArtifact.


        :param artifact_types: The artifact_types of this ModelArtifact.  # noqa: E501
        :type artifact_types: list[ArtifactTypesEnum]
        """
        if self.local_vars_configuration.client_side_validation and artifact_types is None:  # noqa: E501
            raise ValueError("Invalid value for `artifact_types`, must not be `None`")  # noqa: E501

        self._artifact_types = artifact_types

    @property
    def metadata(self):
        """Gets the metadata of this ModelArtifact.  # noqa: E501


        :return: The metadata of this ModelArtifact.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this ModelArtifact.


        :param metadata: The metadata of this ModelArtifact.  # noqa: E501
        :type metadata: dict(str, object)
        """
        if self.local_vars_configuration.client_side_validation and metadata is None:  # noqa: E501
            raise ValueError("Invalid value for `metadata`, must not be `None`")  # noqa: E501

        self._metadata = metadata

    @property
    def url(self):
        """Gets the url of this ModelArtifact.  # noqa: E501


        :return: The url of this ModelArtifact.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this ModelArtifact.


        :param url: The url of this ModelArtifact.  # noqa: E501
        :type url: str
        """
        if self.local_vars_configuration.client_side_validation and url is None:  # noqa: E501
            raise ValueError("Invalid value for `url`, must not be `None`")  # noqa: E501

        self._url = url

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModelArtifact):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ModelArtifact):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import printnanny_api_client
from printnanny_api_client.api.remote_control_api import RemoteControlApi  # noqa: E501
from printnanny_api_client.rest import ApiException


class TestRemoteControlApi(unittest.TestCase):
    """RemoteControlApi unit test stubs"""

    def setUp(self):
        self.api = printnanny_api_client.api.remote_control_api.RemoteControlApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_commands_list(self):
        """Test case for commands_list

        """
        pass

    def test_commands_partial_update(self):
        """Test case for commands_partial_update

        """
        pass

    def test_commands_retrieve(self):
        """Test case for commands_retrieve

        """
        pass

    def test_commands_update(self):
        """Test case for commands_update

        """
        pass

    def test_gcode_files_create(self):
        """Test case for gcode_files_create

        """
        pass

    def test_gcode_files_list(self):
        """Test case for gcode_files_list

        """
        pass

    def test_gcode_files_partial_update(self):
        """Test case for gcode_files_partial_update

        """
        pass

    def test_gcode_files_retrieve(self):
        """Test case for gcode_files_retrieve

        """
        pass

    def test_gcode_files_update(self):
        """Test case for gcode_files_update

        """
        pass

    def test_gcode_files_update_or_create(self):
        """Test case for gcode_files_update_or_create

        """
        pass

    def test_octoprint_devices_create(self):
        """Test case for octoprint_devices_create

        """
        pass

    def test_octoprint_devices_list(self):
        """Test case for octoprint_devices_list

        """
        pass

    def test_octoprint_devices_partial_update(self):
        """Test case for octoprint_devices_partial_update

        """
        pass

    def test_octoprint_devices_retrieve(self):
        """Test case for octoprint_devices_retrieve

        """
        pass

    def test_octoprint_devices_update(self):
        """Test case for octoprint_devices_update

        """
        pass

    def test_octoprint_devices_update_or_create(self):
        """Test case for octoprint_devices_update_or_create

        """
        pass

    def test_print_session_partial_update(self):
        """Test case for print_session_partial_update

        """
        pass

    def test_print_session_update(self):
        """Test case for print_session_update

        """
        pass

    def test_print_sessions_create(self):
        """Test case for print_sessions_create

        """
        pass

    def test_print_sessions_list(self):
        """Test case for print_sessions_list

        """
        pass

    def test_print_sessions_retrieve(self):
        """Test case for print_sessions_retrieve

        """
        pass

    def test_printer_profiles_create(self):
        """Test case for printer_profiles_create

        """
        pass

    def test_printer_profiles_list(self):
        """Test case for printer_profiles_list

        """
        pass

    def test_printer_profiles_partial_update(self):
        """Test case for printer_profiles_partial_update

        """
        pass

    def test_printer_profiles_retrieve(self):
        """Test case for printer_profiles_retrieve

        """
        pass

    def test_printer_profiles_update(self):
        """Test case for printer_profiles_update

        """
        pass

    def test_printer_profiles_update_or_create(self):
        """Test case for printer_profiles_update_or_create

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class OctoprintPiSupportRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'model': 'str',
        'throttle_state': 'str',
        'octopi_version': 'str'
    }

    attribute_map = {
        'model': 'model',
        'throttle_state': 'throttle_state',
        'octopi_version': 'octopi_version'
    }

    def __init__(self, model=None, throttle_state=None, octopi_version=None, local_vars_configuration=None):  # noqa: E501
        """OctoprintPiSupportRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._model = None
        self._throttle_state = None
        self._octopi_version = None
        self.discriminator = None

        self.model = model
        self.throttle_state = throttle_state
        if octopi_version is not None:
            self.octopi_version = octopi_version

    @property
    def model(self):
        """Gets the model of this OctoprintPiSupportRequest.  # noqa: E501


        :return: The model of this OctoprintPiSupportRequest.  # noqa: E501
        :rtype: str
        """
        return self._model

    @model.setter
    def model(self, model):
        """Sets the model of this OctoprintPiSupportRequest.


        :param model: The model of this OctoprintPiSupportRequest.  # noqa: E501
        :type model: str
        """
        if self.local_vars_configuration.client_side_validation and model is None:  # noqa: E501
            raise ValueError("Invalid value for `model`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                model is not None and len(model) < 1):
            raise ValueError("Invalid value for `model`, length must be greater than or equal to `1`")  # noqa: E501

        self._model = model

    @property
    def throttle_state(self):
        """Gets the throttle_state of this OctoprintPiSupportRequest.  # noqa: E501


        :return: The throttle_state of this OctoprintPiSupportRequest.  # noqa: E501
        :rtype: str
        """
        return self._throttle_state

    @throttle_state.setter
    def throttle_state(self, throttle_state):
        """Sets the throttle_state of this OctoprintPiSupportRequest.


        :param throttle_state: The throttle_state of this OctoprintPiSupportRequest.  # noqa: E501
        :type throttle_state: str
        """
        if self.local_vars_configuration.client_side_validation and throttle_state is None:  # noqa: E501
            raise ValueError("Invalid value for `throttle_state`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                throttle_state is not None and len(throttle_state) < 1):
            raise ValueError("Invalid value for `throttle_state`, length must be greater than or equal to `1`")  # noqa: E501

        self._throttle_state = throttle_state

    @property
    def octopi_version(self):
        """Gets the octopi_version of this OctoprintPiSupportRequest.  # noqa: E501


        :return: The octopi_version of this OctoprintPiSupportRequest.  # noqa: E501
        :rtype: str
        """
        return self._octopi_version

    @octopi_version.setter
    def octopi_version(self, octopi_version):
        """Sets the octopi_version of this OctoprintPiSupportRequest.


        :param octopi_version: The octopi_version of this OctoprintPiSupportRequest.  # noqa: E501
        :type octopi_version: str
        """
        if (self.local_vars_configuration.client_side_validation and
                octopi_version is not None and len(octopi_version) < 1):
            raise ValueError("Invalid value for `octopi_version`, length must be greater than or equal to `1`")  # noqa: E501

        self._octopi_version = octopi_version

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OctoprintPiSupportRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OctoprintPiSupportRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import printnanny_api_client
from printnanny_api_client.models.paginated_printer_profile_list import PaginatedPrinterProfileList  # noqa: E501
from printnanny_api_client.rest import ApiException

class TestPaginatedPrinterProfileList(unittest.TestCase):
    """PaginatedPrinterProfileList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PaginatedPrinterProfileList
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = printnanny_api_client.models.paginated_printer_profile_list.PaginatedPrinterProfileList()  # noqa: E501
        if include_optional :
            return PaginatedPrinterProfileList(
                count = 123, 
                next = 'http://api.example.org/accounts/?page=4', 
                previous = 'http://api.example.org/accounts/?page=2', 
                results = [
                    printnanny_api_client.models.printer_profile.PrinterProfile(
                        id = 56, 
                        user = 56, 
                        octoprint_device = 56, 
                        axes_e_inverted = True, 
                        axes_e_speed = -2147483648, 
                        axes_x_speed = -2147483648, 
                        axes_x_inverted = True, 
                        axes_y_inverted = True, 
                        axes_y_speed = -2147483648, 
                        axes_z_inverted = True, 
                        axes_z_speed = -2147483648, 
                        extruder_count = -2147483648, 
                        extruder_nozzle_diameter = 1.337, 
                        extruder_shared_nozzle = True, 
                        heated_bed = True, 
                        heated_chamber = True, 
                        model = '', 
                        name = '', 
                        octoprint_key = '', 
                        volume_custom_box = {
                            'key' : null
                            }, 
                        volume_depth = 1.337, 
                        volume_formfactor = '', 
                        volume_height = 1.337, 
                        volume_origin = '', 
                        volume_width = 1.337, 
                        url = '', )
                    ]
            )
        else :
            return PaginatedPrinterProfileList(
        )

    def testPaginatedPrinterProfileList(self):
        """Test PaginatedPrinterProfileList"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


from setuptools import setup, find_namespace_packages  # noqa: H301

NAME = "printnanny-api-client"
VERSION = "0.39.1"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.25.3", "six >= 1.10", "python-dateutil", "protobuf"]
REQUIRES.append("aiohttp >= 3.7.0")
setup(
    name=NAME,
    version=VERSION,
    description="printnanny-api-client",
    author="Leigh Johnson",
    author_email="leigh@print-nanny.com",
    url="",
    keywords=["OpenAPI", "OpenAPI-Generator", "printnanny-api-client"],
    install_requires=REQUIRES,
    packages=find_namespace_packages(exclude=["test", "tests"]),
    include_package_data=True,
    license="AGPLv3",
    long_description="""\
    Official API client library for print-nanny.com  # noqa: E501
    """
)



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class Device(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'cloudiot_device': 'CloudiotDevice',
        'cameras': 'list[Camera]',
        'janus_local_url': 'str',
        'dashboard_url': 'str',
        'printer_controllers': 'list[PrinterController]',
        'release_channel': 'ReleaseChannelEnum',
        'monitoring_active': 'bool',
        'user': 'User',
        'last_task': 'Task',
        'active_tasks': 'list[Task]',
        'active_cameras': 'list[Camera]',
        'created_dt': 'datetime',
        'updated_dt': 'datetime',
        'hostname': 'str'
    }

    attribute_map = {
        'id': 'id',
        'cloudiot_device': 'cloudiot_device',
        'cameras': 'cameras',
        'janus_local_url': 'janus_local_url',
        'dashboard_url': 'dashboard_url',
        'printer_controllers': 'printer_controllers',
        'release_channel': 'release_channel',
        'monitoring_active': 'monitoring_active',
        'user': 'user',
        'last_task': 'last_task',
        'active_tasks': 'active_tasks',
        'active_cameras': 'active_cameras',
        'created_dt': 'created_dt',
        'updated_dt': 'updated_dt',
        'hostname': 'hostname'
    }

    def __init__(self, id=None, cloudiot_device=None, cameras=None, janus_local_url=None, dashboard_url=None, printer_controllers=None, release_channel=None, monitoring_active=False, user=None, last_task=None, active_tasks=None, active_cameras=None, created_dt=None, updated_dt=None, hostname=None, local_vars_configuration=None):  # noqa: E501
        """Device - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._cloudiot_device = None
        self._cameras = None
        self._janus_local_url = None
        self._dashboard_url = None
        self._printer_controllers = None
        self._release_channel = None
        self._monitoring_active = None
        self._user = None
        self._last_task = None
        self._active_tasks = None
        self._active_cameras = None
        self._created_dt = None
        self._updated_dt = None
        self._hostname = None
        self.discriminator = None

        self.id = id
        self.cloudiot_device = cloudiot_device
        self.cameras = cameras
        self.janus_local_url = janus_local_url
        self.dashboard_url = dashboard_url
        self.printer_controllers = printer_controllers
        self.release_channel = release_channel
        if monitoring_active is not None:
            self.monitoring_active = monitoring_active
        self.user = user
        self.last_task = last_task
        self.active_tasks = active_tasks
        self.active_cameras = active_cameras
        self.created_dt = created_dt
        self.updated_dt = updated_dt
        if hostname is not None:
            self.hostname = hostname

    @property
    def id(self):
        """Gets the id of this Device.  # noqa: E501


        :return: The id of this Device.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Device.


        :param id: The id of this Device.  # noqa: E501
        :type id: int
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def cloudiot_device(self):
        """Gets the cloudiot_device of this Device.  # noqa: E501


        :return: The cloudiot_device of this Device.  # noqa: E501
        :rtype: CloudiotDevice
        """
        return self._cloudiot_device

    @cloudiot_device.setter
    def cloudiot_device(self, cloudiot_device):
        """Sets the cloudiot_device of this Device.


        :param cloudiot_device: The cloudiot_device of this Device.  # noqa: E501
        :type cloudiot_device: CloudiotDevice
        """

        self._cloudiot_device = cloudiot_device

    @property
    def cameras(self):
        """Gets the cameras of this Device.  # noqa: E501


        :return: The cameras of this Device.  # noqa: E501
        :rtype: list[Camera]
        """
        return self._cameras

    @cameras.setter
    def cameras(self, cameras):
        """Sets the cameras of this Device.


        :param cameras: The cameras of this Device.  # noqa: E501
        :type cameras: list[Camera]
        """
        if self.local_vars_configuration.client_side_validation and cameras is None:  # noqa: E501
            raise ValueError("Invalid value for `cameras`, must not be `None`")  # noqa: E501

        self._cameras = cameras

    @property
    def janus_local_url(self):
        """Gets the janus_local_url of this Device.  # noqa: E501


        :return: The janus_local_url of this Device.  # noqa: E501
        :rtype: str
        """
        return self._janus_local_url

    @janus_local_url.setter
    def janus_local_url(self, janus_local_url):
        """Sets the janus_local_url of this Device.


        :param janus_local_url: The janus_local_url of this Device.  # noqa: E501
        :type janus_local_url: str
        """
        if self.local_vars_configuration.client_side_validation and janus_local_url is None:  # noqa: E501
            raise ValueError("Invalid value for `janus_local_url`, must not be `None`")  # noqa: E501

        self._janus_local_url = janus_local_url

    @property
    def dashboard_url(self):
        """Gets the dashboard_url of this Device.  # noqa: E501


        :return: The dashboard_url of this Device.  # noqa: E501
        :rtype: str
        """
        return self._dashboard_url

    @dashboard_url.setter
    def dashboard_url(self, dashboard_url):
        """Sets the dashboard_url of this Device.


        :param dashboard_url: The dashboard_url of this Device.  # noqa: E501
        :type dashboard_url: str
        """
        if self.local_vars_configuration.client_side_validation and dashboard_url is None:  # noqa: E501
            raise ValueError("Invalid value for `dashboard_url`, must not be `None`")  # noqa: E501

        self._dashboard_url = dashboard_url

    @property
    def printer_controllers(self):
        """Gets the printer_controllers of this Device.  # noqa: E501


        :return: The printer_controllers of this Device.  # noqa: E501
        :rtype: list[PrinterController]
        """
        return self._printer_controllers

    @printer_controllers.setter
    def printer_controllers(self, printer_controllers):
        """Sets the printer_controllers of this Device.


        :param printer_controllers: The printer_controllers of this Device.  # noqa: E501
        :type printer_controllers: list[PrinterController]
        """
        if self.local_vars_configuration.client_side_validation and printer_controllers is None:  # noqa: E501
            raise ValueError("Invalid value for `printer_controllers`, must not be `None`")  # noqa: E501

        self._printer_controllers = printer_controllers

    @property
    def release_channel(self):
        """Gets the release_channel of this Device.  # noqa: E501


        :return: The release_channel of this Device.  # noqa: E501
        :rtype: ReleaseChannelEnum
        """
        return self._release_channel

    @release_channel.setter
    def release_channel(self, release_channel):
        """Sets the release_channel of this Device.


        :param release_channel: The release_channel of this Device.  # noqa: E501
        :type release_channel: ReleaseChannelEnum
        """

        self._release_channel = release_channel

    @property
    def monitoring_active(self):
        """Gets the monitoring_active of this Device.  # noqa: E501


        :return: The monitoring_active of this Device.  # noqa: E501
        :rtype: bool
        """
        return self._monitoring_active

    @monitoring_active.setter
    def monitoring_active(self, monitoring_active):
        """Sets the monitoring_active of this Device.


        :param monitoring_active: The monitoring_active of this Device.  # noqa: E501
        :type monitoring_active: bool
        """

        self._monitoring_active = monitoring_active

    @property
    def user(self):
        """Gets the user of this Device.  # noqa: E501


        :return: The user of this Device.  # noqa: E501
        :rtype: User
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this Device.


        :param user: The user of this Device.  # noqa: E501
        :type user: User
        """

        self._user = user

    @property
    def last_task(self):
        """Gets the last_task of this Device.  # noqa: E501


        :return: The last_task of this Device.  # noqa: E501
        :rtype: Task
        """
        return self._last_task

    @last_task.setter
    def last_task(self, last_task):
        """Sets the last_task of this Device.


        :param last_task: The last_task of this Device.  # noqa: E501
        :type last_task: Task
        """

        self._last_task = last_task

    @property
    def active_tasks(self):
        """Gets the active_tasks of this Device.  # noqa: E501


        :return: The active_tasks of this Device.  # noqa: E501
        :rtype: list[Task]
        """
        return self._active_tasks

    @active_tasks.setter
    def active_tasks(self, active_tasks):
        """Sets the active_tasks of this Device.


        :param active_tasks: The active_tasks of this Device.  # noqa: E501
        :type active_tasks: list[Task]
        """
        if self.local_vars_configuration.client_side_validation and active_tasks is None:  # noqa: E501
            raise ValueError("Invalid value for `active_tasks`, must not be `None`")  # noqa: E501

        self._active_tasks = active_tasks

    @property
    def active_cameras(self):
        """Gets the active_cameras of this Device.  # noqa: E501


        :return: The active_cameras of this Device.  # noqa: E501
        :rtype: list[Camera]
        """
        return self._active_cameras

    @active_cameras.setter
    def active_cameras(self, active_cameras):
        """Sets the active_cameras of this Device.


        :param active_cameras: The active_cameras of this Device.  # noqa: E501
        :type active_cameras: list[Camera]
        """
        if self.local_vars_configuration.client_side_validation and active_cameras is None:  # noqa: E501
            raise ValueError("Invalid value for `active_cameras`, must not be `None`")  # noqa: E501

        self._active_cameras = active_cameras

    @property
    def created_dt(self):
        """Gets the created_dt of this Device.  # noqa: E501


        :return: The created_dt of this Device.  # noqa: E501
        :rtype: datetime
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this Device.


        :param created_dt: The created_dt of this Device.  # noqa: E501
        :type created_dt: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_dt is None:  # noqa: E501
            raise ValueError("Invalid value for `created_dt`, must not be `None`")  # noqa: E501

        self._created_dt = created_dt

    @property
    def updated_dt(self):
        """Gets the updated_dt of this Device.  # noqa: E501


        :return: The updated_dt of this Device.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_dt

    @updated_dt.setter
    def updated_dt(self, updated_dt):
        """Sets the updated_dt of this Device.


        :param updated_dt: The updated_dt of this Device.  # noqa: E501
        :type updated_dt: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_dt is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_dt`, must not be `None`")  # noqa: E501

        self._updated_dt = updated_dt

    @property
    def hostname(self):
        """Gets the hostname of this Device.  # noqa: E501

        Please enter the hostname you set in the Raspberry Pi Imager's Advanced Options menu (without .local extension)  # noqa: E501

        :return: The hostname of this Device.  # noqa: E501
        :rtype: str
        """
        return self._hostname

    @hostname.setter
    def hostname(self, hostname):
        """Sets the hostname of this Device.

        Please enter the hostname you set in the Raspberry Pi Imager's Advanced Options menu (without .local extension)  # noqa: E501

        :param hostname: The hostname of this Device.  # noqa: E501
        :type hostname: str
        """
        if (self.local_vars_configuration.client_side_validation and
                hostname is not None and len(hostname) > 255):
            raise ValueError("Invalid value for `hostname`, length must be less than or equal to `255`")  # noqa: E501

        self._hostname = hostname

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Device):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Device):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class License(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'printnanny_env': 'PrintnannyEnvEnum',
        'activated': 'bool',
        'user': 'int',
        'cloudiot_device': 'int',
        'janus_admin_secret': 'str',
        'janus_token': 'str',
        'public_key': 'str',
        'fingerprint': 'str',
        'created_dt': 'datetime',
        'updated_dt': 'datetime',
        'device': 'int'
    }

    attribute_map = {
        'id': 'id',
        'printnanny_env': 'printnanny_env',
        'activated': 'activated',
        'user': 'user',
        'cloudiot_device': 'cloudiot_device',
        'janus_admin_secret': 'janus_admin_secret',
        'janus_token': 'janus_token',
        'public_key': 'public_key',
        'fingerprint': 'fingerprint',
        'created_dt': 'created_dt',
        'updated_dt': 'updated_dt',
        'device': 'device'
    }

    def __init__(self, id=None, printnanny_env=None, activated=False, user=None, cloudiot_device=None, janus_admin_secret=None, janus_token=None, public_key=None, fingerprint=None, created_dt=None, updated_dt=None, device=None, local_vars_configuration=None):  # noqa: E501
        """License - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._printnanny_env = None
        self._activated = None
        self._user = None
        self._cloudiot_device = None
        self._janus_admin_secret = None
        self._janus_token = None
        self._public_key = None
        self._fingerprint = None
        self._created_dt = None
        self._updated_dt = None
        self._device = None
        self.discriminator = None

        self.id = id
        self.printnanny_env = printnanny_env
        if activated is not None:
            self.activated = activated
        self.user = user
        self.cloudiot_device = cloudiot_device
        if janus_admin_secret is not None:
            self.janus_admin_secret = janus_admin_secret
        if janus_token is not None:
            self.janus_token = janus_token
        self.public_key = public_key
        self.fingerprint = fingerprint
        self.created_dt = created_dt
        self.updated_dt = updated_dt
        self.device = device

    @property
    def id(self):
        """Gets the id of this License.  # noqa: E501


        :return: The id of this License.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this License.


        :param id: The id of this License.  # noqa: E501
        :type id: int
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def printnanny_env(self):
        """Gets the printnanny_env of this License.  # noqa: E501


        :return: The printnanny_env of this License.  # noqa: E501
        :rtype: PrintnannyEnvEnum
        """
        return self._printnanny_env

    @printnanny_env.setter
    def printnanny_env(self, printnanny_env):
        """Sets the printnanny_env of this License.


        :param printnanny_env: The printnanny_env of this License.  # noqa: E501
        :type printnanny_env: PrintnannyEnvEnum
        """

        self._printnanny_env = printnanny_env

    @property
    def activated(self):
        """Gets the activated of this License.  # noqa: E501


        :return: The activated of this License.  # noqa: E501
        :rtype: bool
        """
        return self._activated

    @activated.setter
    def activated(self, activated):
        """Sets the activated of this License.


        :param activated: The activated of this License.  # noqa: E501
        :type activated: bool
        """

        self._activated = activated

    @property
    def user(self):
        """Gets the user of this License.  # noqa: E501


        :return: The user of this License.  # noqa: E501
        :rtype: int
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this License.


        :param user: The user of this License.  # noqa: E501
        :type user: int
        """
        if self.local_vars_configuration.client_side_validation and user is None:  # noqa: E501
            raise ValueError("Invalid value for `user`, must not be `None`")  # noqa: E501

        self._user = user

    @property
    def cloudiot_device(self):
        """Gets the cloudiot_device of this License.  # noqa: E501


        :return: The cloudiot_device of this License.  # noqa: E501
        :rtype: int
        """
        return self._cloudiot_device

    @cloudiot_device.setter
    def cloudiot_device(self, cloudiot_device):
        """Sets the cloudiot_device of this License.


        :param cloudiot_device: The cloudiot_device of this License.  # noqa: E501
        :type cloudiot_device: int
        """
        if self.local_vars_configuration.client_side_validation and cloudiot_device is None:  # noqa: E501
            raise ValueError("Invalid value for `cloudiot_device`, must not be `None`")  # noqa: E501

        self._cloudiot_device = cloudiot_device

    @property
    def janus_admin_secret(self):
        """Gets the janus_admin_secret of this License.  # noqa: E501


        :return: The janus_admin_secret of this License.  # noqa: E501
        :rtype: str
        """
        return self._janus_admin_secret

    @janus_admin_secret.setter
    def janus_admin_secret(self, janus_admin_secret):
        """Sets the janus_admin_secret of this License.


        :param janus_admin_secret: The janus_admin_secret of this License.  # noqa: E501
        :type janus_admin_secret: str
        """
        if (self.local_vars_configuration.client_side_validation and
                janus_admin_secret is not None and len(janus_admin_secret) > 255):
            raise ValueError("Invalid value for `janus_admin_secret`, length must be less than or equal to `255`")  # noqa: E501

        self._janus_admin_secret = janus_admin_secret

    @property
    def janus_token(self):
        """Gets the janus_token of this License.  # noqa: E501


        :return: The janus_token of this License.  # noqa: E501
        :rtype: str
        """
        return self._janus_token

    @janus_token.setter
    def janus_token(self, janus_token):
        """Sets the janus_token of this License.


        :param janus_token: The janus_token of this License.  # noqa: E501
        :type janus_token: str
        """
        if (self.local_vars_configuration.client_side_validation and
                janus_token is not None and len(janus_token) > 255):
            raise ValueError("Invalid value for `janus_token`, length must be less than or equal to `255`")  # noqa: E501

        self._janus_token = janus_token

    @property
    def public_key(self):
        """Gets the public_key of this License.  # noqa: E501


        :return: The public_key of this License.  # noqa: E501
        :rtype: str
        """
        return self._public_key

    @public_key.setter
    def public_key(self, public_key):
        """Sets the public_key of this License.


        :param public_key: The public_key of this License.  # noqa: E501
        :type public_key: str
        """
        if self.local_vars_configuration.client_side_validation and public_key is None:  # noqa: E501
            raise ValueError("Invalid value for `public_key`, must not be `None`")  # noqa: E501

        self._public_key = public_key

    @property
    def fingerprint(self):
        """Gets the fingerprint of this License.  # noqa: E501


        :return: The fingerprint of this License.  # noqa: E501
        :rtype: str
        """
        return self._fingerprint

    @fingerprint.setter
    def fingerprint(self, fingerprint):
        """Sets the fingerprint of this License.


        :param fingerprint: The fingerprint of this License.  # noqa: E501
        :type fingerprint: str
        """
        if self.local_vars_configuration.client_side_validation and fingerprint is None:  # noqa: E501
            raise ValueError("Invalid value for `fingerprint`, must not be `None`")  # noqa: E501

        self._fingerprint = fingerprint

    @property
    def created_dt(self):
        """Gets the created_dt of this License.  # noqa: E501


        :return: The created_dt of this License.  # noqa: E501
        :rtype: datetime
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this License.


        :param created_dt: The created_dt of this License.  # noqa: E501
        :type created_dt: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_dt is None:  # noqa: E501
            raise ValueError("Invalid value for `created_dt`, must not be `None`")  # noqa: E501

        self._created_dt = created_dt

    @property
    def updated_dt(self):
        """Gets the updated_dt of this License.  # noqa: E501


        :return: The updated_dt of this License.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_dt

    @updated_dt.setter
    def updated_dt(self, updated_dt):
        """Sets the updated_dt of this License.


        :param updated_dt: The updated_dt of this License.  # noqa: E501
        :type updated_dt: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_dt is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_dt`, must not be `None`")  # noqa: E501

        self._updated_dt = updated_dt

    @property
    def device(self):
        """Gets the device of this License.  # noqa: E501


        :return: The device of this License.  # noqa: E501
        :rtype: int
        """
        return self._device

    @device.setter
    def device(self, device):
        """Sets the device of this License.


        :param device: The device of this License.  # noqa: E501
        :type device: int
        """
        if self.local_vars_configuration.client_side_validation and device is None:  # noqa: E501
            raise ValueError("Invalid value for `device`, must not be `None`")  # noqa: E501

        self._device = device

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, License):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, License):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class OctoPrintNannyEvent(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    allowed enum values
    """
    MONITORING_START = "plugin_octoprint_nanny_monitoring_start"
    MONITORING_STOP = "plugin_octoprint_nanny_monitoring_stop"
    MONITORING_RESET = "plugin_octoprint_nanny_monitoring_reset"
    DEVICE_REGISTER_START = "plugin_octoprint_nanny_device_register_start"
    DEVICE_REGISTER_DONE = "plugin_octoprint_nanny_device_register_done"
    DEVICE_REGISTER_FAILED = "plugin_octoprint_nanny_device_register_failed"
    DEVICE_RESET = "plugin_octoprint_nanny_device_reset"
    PRINTER_PROFILE_SYNC_START = "plugin_octoprint_nanny_printer_profile_sync_start"
    PRINTER_PROFILE_SYNC_DONE = "plugin_octoprint_nanny_printer_profile_sync_done"
    PRINTER_PROFILE_SYNC_FAILED = "plugin_octoprint_nanny_printer_profile_sync_failed"
    CONNECT_TEST_REST_API = "plugin_octoprint_nanny_connect_test_rest_api"
    CONNECT_TEST_REST_API_FAILED = "plugin_octoprint_nanny_connect_test_rest_api_failed"
    CONNECT_TEST_REST_API_SUCCESS = "plugin_octoprint_nanny_connect_test_rest_api_success"
    CONNECT_TEST_MQTT_PING = "plugin_octoprint_nanny_connect_test_mqtt_ping"
    CONNECT_TEST_MQTT_PING_FAILED = "plugin_octoprint_nanny_connect_test_mqtt_ping_failed"
    CONNECT_TEST_MQTT_PING_SUCCESS = "plugin_octoprint_nanny_connect_test_mqtt_ping_success"
    CONNECT_TEST_MQTT_PONG = "plugin_octoprint_nanny_connect_test_mqtt_pong"
    CONNECT_TEST_MQTT_PONG_FAILED = "plugin_octoprint_nanny_connect_test_mqtt_pong_failed"
    CONNECT_TEST_MQTT_PONG_SUCCESS = "plugin_octoprint_nanny_connect_test_mqtt_pong_success"

    allowable_values = [MONITORING_START, MONITORING_STOP, MONITORING_RESET, DEVICE_REGISTER_START, DEVICE_REGISTER_DONE, DEVICE_REGISTER_FAILED, DEVICE_RESET, PRINTER_PROFILE_SYNC_START, PRINTER_PROFILE_SYNC_DONE, PRINTER_PROFILE_SYNC_FAILED, CONNECT_TEST_REST_API, CONNECT_TEST_REST_API_FAILED, CONNECT_TEST_REST_API_SUCCESS, CONNECT_TEST_MQTT_PING, CONNECT_TEST_MQTT_PING_FAILED, CONNECT_TEST_MQTT_PING_SUCCESS, CONNECT_TEST_MQTT_PONG, CONNECT_TEST_MQTT_PONG_FAILED, CONNECT_TEST_MQTT_PONG_SUCCESS]  # noqa: E501

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
    }

    attribute_map = {
    }

    def __init__(self, local_vars_configuration=None):  # noqa: E501
        """OctoPrintNannyEvent - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration
        self.discriminator = None

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OctoPrintNannyEvent):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OctoPrintNannyEvent):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class OctoPrintDevice(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'created_dt': 'datetime',
        'name': 'str',
        'user': 'int',
        'public_key': 'str',
        'fingerprint': 'str',
        'cloudiot_device': 'dict(str, object)',
        'cloudiot_device_name': 'str',
        'cloudiot_device_path': 'str',
        'cloudiot_device_num_id': 'int',
        'model': 'str',
        'platform': 'str',
        'cpu_flags': 'list[str]',
        'hardware': 'str',
        'revision': 'str',
        'serial': 'str',
        'cores': 'int',
        'ram': 'int',
        'python_version': 'str',
        'pip_version': 'str',
        'virtualenv': 'str',
        'octoprint_version': 'str',
        'plugin_version': 'str',
        'print_nanny_client_version': 'str',
        'print_nanny_beta_client_version': 'str',
        'cloudiot_device_configs': 'str',
        'manage_url': 'str',
        'monitoring_active': 'bool',
        'active_session': 'PrintSession'
    }

    attribute_map = {
        'id': 'id',
        'created_dt': 'created_dt',
        'name': 'name',
        'user': 'user',
        'public_key': 'public_key',
        'fingerprint': 'fingerprint',
        'cloudiot_device': 'cloudiot_device',
        'cloudiot_device_name': 'cloudiot_device_name',
        'cloudiot_device_path': 'cloudiot_device_path',
        'cloudiot_device_num_id': 'cloudiot_device_num_id',
        'model': 'model',
        'platform': 'platform',
        'cpu_flags': 'cpu_flags',
        'hardware': 'hardware',
        'revision': 'revision',
        'serial': 'serial',
        'cores': 'cores',
        'ram': 'ram',
        'python_version': 'python_version',
        'pip_version': 'pip_version',
        'virtualenv': 'virtualenv',
        'octoprint_version': 'octoprint_version',
        'plugin_version': 'plugin_version',
        'print_nanny_client_version': 'print_nanny_client_version',
        'print_nanny_beta_client_version': 'print_nanny_beta_client_version',
        'cloudiot_device_configs': 'cloudiot_device_configs',
        'manage_url': 'manage_url',
        'monitoring_active': 'monitoring_active',
        'active_session': 'active_session'
    }

    def __init__(self, id=None, created_dt=None, name=None, user=None, public_key=None, fingerprint=None, cloudiot_device=None, cloudiot_device_name=None, cloudiot_device_path=None, cloudiot_device_num_id=None, model=None, platform=None, cpu_flags=None, hardware=None, revision=None, serial=None, cores=None, ram=None, python_version=None, pip_version=None, virtualenv=None, octoprint_version=None, plugin_version=None, print_nanny_client_version=None, print_nanny_beta_client_version=None, cloudiot_device_configs=None, manage_url=None, monitoring_active=None, active_session=None, local_vars_configuration=None):  # noqa: E501
        """OctoPrintDevice - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._created_dt = None
        self._name = None
        self._user = None
        self._public_key = None
        self._fingerprint = None
        self._cloudiot_device = None
        self._cloudiot_device_name = None
        self._cloudiot_device_path = None
        self._cloudiot_device_num_id = None
        self._model = None
        self._platform = None
        self._cpu_flags = None
        self._hardware = None
        self._revision = None
        self._serial = None
        self._cores = None
        self._ram = None
        self._python_version = None
        self._pip_version = None
        self._virtualenv = None
        self._octoprint_version = None
        self._plugin_version = None
        self._print_nanny_client_version = None
        self._print_nanny_beta_client_version = None
        self._cloudiot_device_configs = None
        self._manage_url = None
        self._monitoring_active = None
        self._active_session = None
        self.discriminator = None

        self.id = id
        self.created_dt = created_dt
        self.name = name
        self.user = user
        self.public_key = public_key
        self.fingerprint = fingerprint
        self.cloudiot_device = cloudiot_device
        self.cloudiot_device_name = cloudiot_device_name
        self.cloudiot_device_path = cloudiot_device_path
        self.cloudiot_device_num_id = cloudiot_device_num_id
        self.model = model
        self.platform = platform
        self.cpu_flags = cpu_flags
        self.hardware = hardware
        self.revision = revision
        self.serial = serial
        self.cores = cores
        self.ram = ram
        self.python_version = python_version
        self.pip_version = pip_version
        self.virtualenv = virtualenv
        self.octoprint_version = octoprint_version
        self.plugin_version = plugin_version
        self.print_nanny_client_version = print_nanny_client_version
        self.print_nanny_beta_client_version = print_nanny_beta_client_version
        self.cloudiot_device_configs = cloudiot_device_configs
        self.manage_url = manage_url
        self.monitoring_active = monitoring_active
        if active_session is not None:
            self.active_session = active_session

    @property
    def id(self):
        """Gets the id of this OctoPrintDevice.  # noqa: E501


        :return: The id of this OctoPrintDevice.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this OctoPrintDevice.


        :param id: The id of this OctoPrintDevice.  # noqa: E501
        :type id: int
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def created_dt(self):
        """Gets the created_dt of this OctoPrintDevice.  # noqa: E501


        :return: The created_dt of this OctoPrintDevice.  # noqa: E501
        :rtype: datetime
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this OctoPrintDevice.


        :param created_dt: The created_dt of this OctoPrintDevice.  # noqa: E501
        :type created_dt: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_dt is None:  # noqa: E501
            raise ValueError("Invalid value for `created_dt`, must not be `None`")  # noqa: E501

        self._created_dt = created_dt

    @property
    def name(self):
        """Gets the name of this OctoPrintDevice.  # noqa: E501


        :return: The name of this OctoPrintDevice.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this OctoPrintDevice.


        :param name: The name of this OctoPrintDevice.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 255):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `255`")  # noqa: E501

        self._name = name

    @property
    def user(self):
        """Gets the user of this OctoPrintDevice.  # noqa: E501


        :return: The user of this OctoPrintDevice.  # noqa: E501
        :rtype: int
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this OctoPrintDevice.


        :param user: The user of this OctoPrintDevice.  # noqa: E501
        :type user: int
        """
        if self.local_vars_configuration.client_side_validation and user is None:  # noqa: E501
            raise ValueError("Invalid value for `user`, must not be `None`")  # noqa: E501

        self._user = user

    @property
    def public_key(self):
        """Gets the public_key of this OctoPrintDevice.  # noqa: E501


        :return: The public_key of this OctoPrintDevice.  # noqa: E501
        :rtype: str
        """
        return self._public_key

    @public_key.setter
    def public_key(self, public_key):
        """Sets the public_key of this OctoPrintDevice.


        :param public_key: The public_key of this OctoPrintDevice.  # noqa: E501
        :type public_key: str
        """
        if self.local_vars_configuration.client_side_validation and public_key is None:  # noqa: E501
            raise ValueError("Invalid value for `public_key`, must not be `None`")  # noqa: E501

        self._public_key = public_key

    @property
    def fingerprint(self):
        """Gets the fingerprint of this OctoPrintDevice.  # noqa: E501


        :return: The fingerprint of this OctoPrintDevice.  # noqa: E501
        :rtype: str
        """
        return self._fingerprint

    @fingerprint.setter
    def fingerprint(self, fingerprint):
        """Sets the fingerprint of this OctoPrintDevice.


        :param fingerprint: The fingerprint of this OctoPrintDevice.  # noqa: E501
        :type fingerprint: str
        """
        if self.local_vars_configuration.client_side_validation and fingerprint is None:  # noqa: E501
            raise ValueError("Invalid value for `fingerprint`, must not be `None`")  # noqa: E501

        self._fingerprint = fingerprint

    @property
    def cloudiot_device(self):
        """Gets the cloudiot_device of this OctoPrintDevice.  # noqa: E501


        :return: The cloudiot_device of this OctoPrintDevice.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._cloudiot_device

    @cloudiot_device.setter
    def cloudiot_device(self, cloudiot_device):
        """Sets the cloudiot_device of this OctoPrintDevice.


        :param cloudiot_device: The cloudiot_device of this OctoPrintDevice.  # noqa: E501
        :type cloudiot_device: dict(str, object)
        """
        if self.local_vars_configuration.client_side_validation and cloudiot_device is None:  # noqa: E501
            raise ValueError("Invalid value for `cloudiot_device`, must not be `None`")  # noqa: E501

        self._cloudiot_device = cloudiot_device

    @property
    def cloudiot_device_name(self):
        """Gets the cloudiot_device_name of this OctoPrintDevice.  # noqa: E501


        :return: The cloudiot_device_name of this OctoPrintDevice.  # noqa: E501
        :rtype: str
        """
        return self._cloudiot_device_name

    @cloudiot_device_name.setter
    def cloudiot_device_name(self, cloudiot_device_name):
        """Sets the cloudiot_device_name of this OctoPrintDevice.


        :param cloudiot_device_name: The cloudiot_device_name of this OctoPrintDevice.  # noqa: E501
        :type cloudiot_device_name: str
        """
        if self.local_vars_configuration.client_side_validation and cloudiot_device_name is None:  # noqa: E501
            raise ValueError("Invalid value for `cloudiot_device_name`, must not be `None`")  # noqa: E501

        self._cloudiot_device_name = cloudiot_device_name

    @property
    def cloudiot_device_path(self):
        """Gets the cloudiot_device_path of this OctoPrintDevice.  # noqa: E501


        :return: The cloudiot_device_path of this OctoPrintDevice.  # noqa: E501
        :rtype: str
        """
        return self._cloudiot_device_path

    @cloudiot_device_path.setter
    def cloudiot_device_path(self, cloudiot_device_path):
        """Sets the cloudiot_device_path of this OctoPrintDevice.


        :param cloudiot_device_path: The cloudiot_device_path of this OctoPrintDevice.  # noqa: E501
        :type cloudiot_device_path: str
        """
        if self.local_vars_configuration.client_side_validation and cloudiot_device_path is None:  # noqa: E501
            raise ValueError("Invalid value for `cloudiot_device_path`, must not be `None`")  # noqa: E501

        self._cloudiot_device_path = cloudiot_device_path

    @property
    def cloudiot_device_num_id(self):
        """Gets the cloudiot_device_num_id of this OctoPrintDevice.  # noqa: E501


        :return: The cloudiot_device_num_id of this OctoPrintDevice.  # noqa: E501
        :rtype: int
        """
        return self._cloudiot_device_num_id

    @cloudiot_device_num_id.setter
    def cloudiot_device_num_id(self, cloudiot_device_num_id):
        """Sets the cloudiot_device_num_id of this OctoPrintDevice.


        :param cloudiot_device_num_id: The cloudiot_device_num_id of this OctoPrintDevice.  # noqa: E501
        :type cloudiot_device_num_id: int
        """
        if self.local_vars_configuration.client_side_validation and cloudiot_device_num_id is None:  # noqa: E501
            raise ValueError("Invalid value for `cloudiot_device_num_id`, must not be `None`")  # noqa: E501

        self._cloudiot_device_num_id = cloudiot_device_num_id

    @property
    def model(self):
        """Gets the model of this OctoPrintDevice.  # noqa: E501


        :return: The model of this OctoPrintDevice.  # noqa: E501
        :rtype: str
        """
        return self._model

    @model.setter
    def model(self, model):
        """Sets the model of this OctoPrintDevice.


        :param model: The model of this OctoPrintDevice.  # noqa: E501
        :type model: str
        """
        if self.local_vars_configuration.client_side_validation and model is None:  # noqa: E501
            raise ValueError("Invalid value for `model`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                model is not None and len(model) > 255):
            raise ValueError("Invalid value for `model`, length must be less than or equal to `255`")  # noqa: E501

        self._model = model

    @property
    def platform(self):
        """Gets the platform of this OctoPrintDevice.  # noqa: E501


        :return: The platform of this OctoPrintDevice.  # noqa: E501
        :rtype: str
        """
        return self._platform

    @platform.setter
    def platform(self, platform):
        """Sets the platform of this OctoPrintDevice.


        :param platform: The platform of this OctoPrintDevice.  # noqa: E501
        :type platform: str
        """
        if self.local_vars_configuration.client_side_validation and platform is None:  # noqa: E501
            raise ValueError("Invalid value for `platform`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                platform is not None and len(platform) > 255):
            raise ValueError("Invalid value for `platform`, length must be less than or equal to `255`")  # noqa: E501

        self._platform = platform

    @property
    def cpu_flags(self):
        """Gets the cpu_flags of this OctoPrintDevice.  # noqa: E501


        :return: The cpu_flags of this OctoPrintDevice.  # noqa: E501
        :rtype: list[str]
        """
        return self._cpu_flags

    @cpu_flags.setter
    def cpu_flags(self, cpu_flags):
        """Sets the cpu_flags of this OctoPrintDevice.


        :param cpu_flags: The cpu_flags of this OctoPrintDevice.  # noqa: E501
        :type cpu_flags: list[str]
        """

        self._cpu_flags = cpu_flags

    @property
    def hardware(self):
        """Gets the hardware of this OctoPrintDevice.  # noqa: E501


        :return: The hardware of this OctoPrintDevice.  # noqa: E501
        :rtype: str
        """
        return self._hardware

    @hardware.setter
    def hardware(self, hardware):
        """Sets the hardware of this OctoPrintDevice.


        :param hardware: The hardware of this OctoPrintDevice.  # noqa: E501
        :type hardware: str
        """
        if (self.local_vars_configuration.client_side_validation and
                hardware is not None and len(hardware) > 255):
            raise ValueError("Invalid value for `hardware`, length must be less than or equal to `255`")  # noqa: E501

        self._hardware = hardware

    @property
    def revision(self):
        """Gets the revision of this OctoPrintDevice.  # noqa: E501


        :return: The revision of this OctoPrintDevice.  # noqa: E501
        :rtype: str
        """
        return self._revision

    @revision.setter
    def revision(self, revision):
        """Sets the revision of this OctoPrintDevice.


        :param revision: The revision of this OctoPrintDevice.  # noqa: E501
        :type revision: str
        """
        if (self.local_vars_configuration.client_side_validation and
                revision is not None and len(revision) > 255):
            raise ValueError("Invalid value for `revision`, length must be less than or equal to `255`")  # noqa: E501

        self._revision = revision

    @property
    def serial(self):
        """Gets the serial of this OctoPrintDevice.  # noqa: E501


        :return: The serial of this OctoPrintDevice.  # noqa: E501
        :rtype: str
        """
        return self._serial

    @serial.setter
    def serial(self, serial):
        """Sets the serial of this OctoPrintDevice.


        :param serial: The serial of this OctoPrintDevice.  # noqa: E501
        :type serial: str
        """
        if self.local_vars_configuration.client_side_validation and serial is None:  # noqa: E501
            raise ValueError("Invalid value for `serial`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                serial is not None and len(serial) > 255):
            raise ValueError("Invalid value for `serial`, length must be less than or equal to `255`")  # noqa: E501

        self._serial = serial

    @property
    def cores(self):
        """Gets the cores of this OctoPrintDevice.  # noqa: E501


        :return: The cores of this OctoPrintDevice.  # noqa: E501
        :rtype: int
        """
        return self._cores

    @cores.setter
    def cores(self, cores):
        """Sets the cores of this OctoPrintDevice.


        :param cores: The cores of this OctoPrintDevice.  # noqa: E501
        :type cores: int
        """
        if self.local_vars_configuration.client_side_validation and cores is None:  # noqa: E501
            raise ValueError("Invalid value for `cores`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                cores is not None and cores > 2147483647):  # noqa: E501
            raise ValueError("Invalid value for `cores`, must be a value less than or equal to `2147483647`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                cores is not None and cores < -2147483648):  # noqa: E501
            raise ValueError("Invalid value for `cores`, must be a value greater than or equal to `-2147483648`")  # noqa: E501

        self._cores = cores

    @property
    def ram(self):
        """Gets the ram of this OctoPrintDevice.  # noqa: E501


        :return: The ram of this OctoPrintDevice.  # noqa: E501
        :rtype: int
        """
        return self._ram

    @ram.setter
    def ram(self, ram):
        """Sets the ram of this OctoPrintDevice.


        :param ram: The ram of this OctoPrintDevice.  # noqa: E501
        :type ram: int
        """
        if self.local_vars_configuration.client_side_validation and ram is None:  # noqa: E501
            raise ValueError("Invalid value for `ram`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                ram is not None and ram > 2147483647):  # noqa: E501
            raise ValueError("Invalid value for `ram`, must be a value less than or equal to `2147483647`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                ram is not None and ram < -2147483648):  # noqa: E501
            raise ValueError("Invalid value for `ram`, must be a value greater than or equal to `-2147483648`")  # noqa: E501

        self._ram = ram

    @property
    def python_version(self):
        """Gets the python_version of this OctoPrintDevice.  # noqa: E501


        :return: The python_version of this OctoPrintDevice.  # noqa: E501
        :rtype: str
        """
        return self._python_version

    @python_version.setter
    def python_version(self, python_version):
        """Sets the python_version of this OctoPrintDevice.


        :param python_version: The python_version of this OctoPrintDevice.  # noqa: E501
        :type python_version: str
        """
        if self.local_vars_configuration.client_side_validation and python_version is None:  # noqa: E501
            raise ValueError("Invalid value for `python_version`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                python_version is not None and len(python_version) > 255):
            raise ValueError("Invalid value for `python_version`, length must be less than or equal to `255`")  # noqa: E501

        self._python_version = python_version

    @property
    def pip_version(self):
        """Gets the pip_version of this OctoPrintDevice.  # noqa: E501


        :return: The pip_version of this OctoPrintDevice.  # noqa: E501
        :rtype: str
        """
        return self._pip_version

    @pip_version.setter
    def pip_version(self, pip_version):
        """Sets the pip_version of this OctoPrintDevice.


        :param pip_version: The pip_version of this OctoPrintDevice.  # noqa: E501
        :type pip_version: str
        """
        if self.local_vars_configuration.client_side_validation and pip_version is None:  # noqa: E501
            raise ValueError("Invalid value for `pip_version`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                pip_version is not None and len(pip_version) > 255):
            raise ValueError("Invalid value for `pip_version`, length must be less than or equal to `255`")  # noqa: E501

        self._pip_version = pip_version

    @property
    def virtualenv(self):
        """Gets the virtualenv of this OctoPrintDevice.  # noqa: E501


        :return: The virtualenv of this OctoPrintDevice.  # noqa: E501
        :rtype: str
        """
        return self._virtualenv

    @virtualenv.setter
    def virtualenv(self, virtualenv):
        """Sets the virtualenv of this OctoPrintDevice.


        :param virtualenv: The virtualenv of this OctoPrintDevice.  # noqa: E501
        :type virtualenv: str
        """
        if (self.local_vars_configuration.client_side_validation and
                virtualenv is not None and len(virtualenv) > 255):
            raise ValueError("Invalid value for `virtualenv`, length must be less than or equal to `255`")  # noqa: E501

        self._virtualenv = virtualenv

    @property
    def octoprint_version(self):
        """Gets the octoprint_version of this OctoPrintDevice.  # noqa: E501


        :return: The octoprint_version of this OctoPrintDevice.  # noqa: E501
        :rtype: str
        """
        return self._octoprint_version

    @octoprint_version.setter
    def octoprint_version(self, octoprint_version):
        """Sets the octoprint_version of this OctoPrintDevice.


        :param octoprint_version: The octoprint_version of this OctoPrintDevice.  # noqa: E501
        :type octoprint_version: str
        """
        if self.local_vars_configuration.client_side_validation and octoprint_version is None:  # noqa: E501
            raise ValueError("Invalid value for `octoprint_version`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                octoprint_version is not None and len(octoprint_version) > 255):
            raise ValueError("Invalid value for `octoprint_version`, length must be less than or equal to `255`")  # noqa: E501

        self._octoprint_version = octoprint_version

    @property
    def plugin_version(self):
        """Gets the plugin_version of this OctoPrintDevice.  # noqa: E501


        :return: The plugin_version of this OctoPrintDevice.  # noqa: E501
        :rtype: str
        """
        return self._plugin_version

    @plugin_version.setter
    def plugin_version(self, plugin_version):
        """Sets the plugin_version of this OctoPrintDevice.


        :param plugin_version: The plugin_version of this OctoPrintDevice.  # noqa: E501
        :type plugin_version: str
        """
        if self.local_vars_configuration.client_side_validation and plugin_version is None:  # noqa: E501
            raise ValueError("Invalid value for `plugin_version`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                plugin_version is not None and len(plugin_version) > 255):
            raise ValueError("Invalid value for `plugin_version`, length must be less than or equal to `255`")  # noqa: E501

        self._plugin_version = plugin_version

    @property
    def print_nanny_client_version(self):
        """Gets the print_nanny_client_version of this OctoPrintDevice.  # noqa: E501


        :return: The print_nanny_client_version of this OctoPrintDevice.  # noqa: E501
        :rtype: str
        """
        return self._print_nanny_client_version

    @print_nanny_client_version.setter
    def print_nanny_client_version(self, print_nanny_client_version):
        """Sets the print_nanny_client_version of this OctoPrintDevice.


        :param print_nanny_client_version: The print_nanny_client_version of this OctoPrintDevice.  # noqa: E501
        :type print_nanny_client_version: str
        """
        if self.local_vars_configuration.client_side_validation and print_nanny_client_version is None:  # noqa: E501
            raise ValueError("Invalid value for `print_nanny_client_version`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                print_nanny_client_version is not None and len(print_nanny_client_version) > 255):
            raise ValueError("Invalid value for `print_nanny_client_version`, length must be less than or equal to `255`")  # noqa: E501

        self._print_nanny_client_version = print_nanny_client_version

    @property
    def print_nanny_beta_client_version(self):
        """Gets the print_nanny_beta_client_version of this OctoPrintDevice.  # noqa: E501


        :return: The print_nanny_beta_client_version of this OctoPrintDevice.  # noqa: E501
        :rtype: str
        """
        return self._print_nanny_beta_client_version

    @print_nanny_beta_client_version.setter
    def print_nanny_beta_client_version(self, print_nanny_beta_client_version):
        """Sets the print_nanny_beta_client_version of this OctoPrintDevice.


        :param print_nanny_beta_client_version: The print_nanny_beta_client_version of this OctoPrintDevice.  # noqa: E501
        :type print_nanny_beta_client_version: str
        """
        if (self.local_vars_configuration.client_side_validation and
                print_nanny_beta_client_version is not None and len(print_nanny_beta_client_version) > 255):
            raise ValueError("Invalid value for `print_nanny_beta_client_version`, length must be less than or equal to `255`")  # noqa: E501

        self._print_nanny_beta_client_version = print_nanny_beta_client_version

    @property
    def cloudiot_device_configs(self):
        """Gets the cloudiot_device_configs of this OctoPrintDevice.  # noqa: E501


        :return: The cloudiot_device_configs of this OctoPrintDevice.  # noqa: E501
        :rtype: str
        """
        return self._cloudiot_device_configs

    @cloudiot_device_configs.setter
    def cloudiot_device_configs(self, cloudiot_device_configs):
        """Sets the cloudiot_device_configs of this OctoPrintDevice.


        :param cloudiot_device_configs: The cloudiot_device_configs of this OctoPrintDevice.  # noqa: E501
        :type cloudiot_device_configs: str
        """
        if self.local_vars_configuration.client_side_validation and cloudiot_device_configs is None:  # noqa: E501
            raise ValueError("Invalid value for `cloudiot_device_configs`, must not be `None`")  # noqa: E501

        self._cloudiot_device_configs = cloudiot_device_configs

    @property
    def manage_url(self):
        """Gets the manage_url of this OctoPrintDevice.  # noqa: E501


        :return: The manage_url of this OctoPrintDevice.  # noqa: E501
        :rtype: str
        """
        return self._manage_url

    @manage_url.setter
    def manage_url(self, manage_url):
        """Sets the manage_url of this OctoPrintDevice.


        :param manage_url: The manage_url of this OctoPrintDevice.  # noqa: E501
        :type manage_url: str
        """
        if self.local_vars_configuration.client_side_validation and manage_url is None:  # noqa: E501
            raise ValueError("Invalid value for `manage_url`, must not be `None`")  # noqa: E501

        self._manage_url = manage_url

    @property
    def monitoring_active(self):
        """Gets the monitoring_active of this OctoPrintDevice.  # noqa: E501


        :return: The monitoring_active of this OctoPrintDevice.  # noqa: E501
        :rtype: bool
        """
        return self._monitoring_active

    @monitoring_active.setter
    def monitoring_active(self, monitoring_active):
        """Sets the monitoring_active of this OctoPrintDevice.


        :param monitoring_active: The monitoring_active of this OctoPrintDevice.  # noqa: E501
        :type monitoring_active: bool
        """
        if self.local_vars_configuration.client_side_validation and monitoring_active is None:  # noqa: E501
            raise ValueError("Invalid value for `monitoring_active`, must not be `None`")  # noqa: E501

        self._monitoring_active = monitoring_active

    @property
    def active_session(self):
        """Gets the active_session of this OctoPrintDevice.  # noqa: E501


        :return: The active_session of this OctoPrintDevice.  # noqa: E501
        :rtype: PrintSession
        """
        return self._active_session

    @active_session.setter
    def active_session(self, active_session):
        """Sets the active_session of this OctoPrintDevice.


        :param active_session: The active_session of this OctoPrintDevice.  # noqa: E501
        :type active_session: PrintSession
        """

        self._active_session = active_session

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OctoPrintDevice):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OctoPrintDevice):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class OctoprintPrinterDataRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'job': 'OctoprintJobRequest',
        'state': 'OctoprintPrinterStateRequest',
        'user': 'str',
        'current_z': 'float',
        'progress': 'OctoprintProgressRequest',
        'resends': 'dict(str, object)',
        'offsets': 'dict(str, object)'
    }

    attribute_map = {
        'job': 'job',
        'state': 'state',
        'user': 'user',
        'current_z': 'currentZ',
        'progress': 'progress',
        'resends': 'resends',
        'offsets': 'offsets'
    }

    def __init__(self, job=None, state=None, user=None, current_z=None, progress=None, resends=None, offsets=None, local_vars_configuration=None):  # noqa: E501
        """OctoprintPrinterDataRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._job = None
        self._state = None
        self._user = None
        self._current_z = None
        self._progress = None
        self._resends = None
        self._offsets = None
        self.discriminator = None

        self.job = job
        self.state = state
        self.user = user
        if current_z is not None:
            self.current_z = current_z
        self.progress = progress
        self.resends = resends
        self.offsets = offsets

    @property
    def job(self):
        """Gets the job of this OctoprintPrinterDataRequest.  # noqa: E501


        :return: The job of this OctoprintPrinterDataRequest.  # noqa: E501
        :rtype: OctoprintJobRequest
        """
        return self._job

    @job.setter
    def job(self, job):
        """Sets the job of this OctoprintPrinterDataRequest.


        :param job: The job of this OctoprintPrinterDataRequest.  # noqa: E501
        :type job: OctoprintJobRequest
        """
        if self.local_vars_configuration.client_side_validation and job is None:  # noqa: E501
            raise ValueError("Invalid value for `job`, must not be `None`")  # noqa: E501

        self._job = job

    @property
    def state(self):
        """Gets the state of this OctoprintPrinterDataRequest.  # noqa: E501


        :return: The state of this OctoprintPrinterDataRequest.  # noqa: E501
        :rtype: OctoprintPrinterStateRequest
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this OctoprintPrinterDataRequest.


        :param state: The state of this OctoprintPrinterDataRequest.  # noqa: E501
        :type state: OctoprintPrinterStateRequest
        """
        if self.local_vars_configuration.client_side_validation and state is None:  # noqa: E501
            raise ValueError("Invalid value for `state`, must not be `None`")  # noqa: E501

        self._state = state

    @property
    def user(self):
        """Gets the user of this OctoprintPrinterDataRequest.  # noqa: E501


        :return: The user of this OctoprintPrinterDataRequest.  # noqa: E501
        :rtype: str
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this OctoprintPrinterDataRequest.


        :param user: The user of this OctoprintPrinterDataRequest.  # noqa: E501
        :type user: str
        """
        if (self.local_vars_configuration.client_side_validation and
                user is not None and len(user) < 1):
            raise ValueError("Invalid value for `user`, length must be greater than or equal to `1`")  # noqa: E501

        self._user = user

    @property
    def current_z(self):
        """Gets the current_z of this OctoprintPrinterDataRequest.  # noqa: E501


        :return: The current_z of this OctoprintPrinterDataRequest.  # noqa: E501
        :rtype: float
        """
        return self._current_z

    @current_z.setter
    def current_z(self, current_z):
        """Sets the current_z of this OctoprintPrinterDataRequest.


        :param current_z: The current_z of this OctoprintPrinterDataRequest.  # noqa: E501
        :type current_z: float
        """

        self._current_z = current_z

    @property
    def progress(self):
        """Gets the progress of this OctoprintPrinterDataRequest.  # noqa: E501


        :return: The progress of this OctoprintPrinterDataRequest.  # noqa: E501
        :rtype: OctoprintProgressRequest
        """
        return self._progress

    @progress.setter
    def progress(self, progress):
        """Sets the progress of this OctoprintPrinterDataRequest.


        :param progress: The progress of this OctoprintPrinterDataRequest.  # noqa: E501
        :type progress: OctoprintProgressRequest
        """
        if self.local_vars_configuration.client_side_validation and progress is None:  # noqa: E501
            raise ValueError("Invalid value for `progress`, must not be `None`")  # noqa: E501

        self._progress = progress

    @property
    def resends(self):
        """Gets the resends of this OctoprintPrinterDataRequest.  # noqa: E501


        :return: The resends of this OctoprintPrinterDataRequest.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._resends

    @resends.setter
    def resends(self, resends):
        """Sets the resends of this OctoprintPrinterDataRequest.


        :param resends: The resends of this OctoprintPrinterDataRequest.  # noqa: E501
        :type resends: dict(str, object)
        """
        if self.local_vars_configuration.client_side_validation and resends is None:  # noqa: E501
            raise ValueError("Invalid value for `resends`, must not be `None`")  # noqa: E501

        self._resends = resends

    @property
    def offsets(self):
        """Gets the offsets of this OctoprintPrinterDataRequest.  # noqa: E501


        :return: The offsets of this OctoprintPrinterDataRequest.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._offsets

    @offsets.setter
    def offsets(self, offsets):
        """Sets the offsets of this OctoprintPrinterDataRequest.


        :param offsets: The offsets of this OctoprintPrinterDataRequest.  # noqa: E501
        :type offsets: dict(str, object)
        """
        if self.local_vars_configuration.client_side_validation and offsets is None:  # noqa: E501
            raise ValueError("Invalid value for `offsets`, must not be `None`")  # noqa: E501

        self._offsets = offsets

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OctoprintPrinterDataRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OctoprintPrinterDataRequest):
            return True

        return self.to_dict() != other.to_dict()
